==> process-infinispan-persistence-springboot-0.13.1-sources.jar: org/acme/deals/DealsModel.java <==
package org.acme.deals;

import java.util.Map;
import java.util.HashMap;

@org.kie.internal.kogito.codegen.Generated(value = "kogito-codegen", reference = "deals", name = "Deals", hidden = false)
public class DealsModel implements org.kie.kogito.Model {

    private String id;

    public void setId(String id) {
        this.id = id;
    }

    public String getId() {
        return this.id;
    }

    @Override
    public Map<String, Object> toMap() {
        Map<String, Object> params = new HashMap();
        params.put("review", this.review);
        params.put("name", this.name);
        params.put("traveller", this.traveller);
        return params;
    }

    @Override
    public void fromMap(Map<String, Object> params) {
        fromMap(null, params);
    }

    public void fromMap(String id, Map<String, Object> params) {
        this.id = id;
        this.review = (java.lang.String) params.get("review");
        this.name = (java.lang.String) params.get("name");
        this.traveller = (org.acme.deals.Traveller) params.get("traveller");
    }

    @org.kie.internal.kogito.codegen.VariableInfo(tags = "")
    @com.fasterxml.jackson.annotation.JsonProperty(value = "review")
    @javax.validation.Valid()
    private java.lang.String review;

    public java.lang.String getReview() {
        return review;
    }

    public void setReview(java.lang.String review) {
        this.review = review;
    }

    @org.kie.internal.kogito.codegen.VariableInfo(tags = "")
    @com.fasterxml.jackson.annotation.JsonProperty(value = "name")
    @javax.validation.Valid()
    private java.lang.String name;

    public java.lang.String getName() {
        return name;
    }

    public void setName(java.lang.String name) {
        this.name = name;
    }

    @org.kie.internal.kogito.codegen.VariableInfo(tags = "")
    @com.fasterxml.jackson.annotation.JsonProperty(value = "traveller")
    @javax.validation.Valid()
    private org.acme.deals.Traveller traveller;

    public org.acme.deals.Traveller getTraveller() {
        return traveller;
    }

    public void setTraveller(org.acme.deals.Traveller traveller) {
        this.traveller = traveller;
    }
}

==> process-infinispan-persistence-springboot-0.16.0-sources.jar: org/acme/deals/DealsModel.java <==
package org.acme.deals;

import java.util.Map;
import java.util.HashMap;

@org.kie.internal.kogito.codegen.Generated(value = "kogito-codegen", reference = "deals", name = "Deals", hidden = false)
public class DealsModel implements org.kie.kogito.Model {

    private String id;

    public void setId(String id) {
        this.id = id;
    }

    public String getId() {
        return this.id;
    }

    @Override
    public Map<String, Object> toMap() {
        Map<String, Object> params = new HashMap();
        params.put("review", this.review);
        params.put("name", this.name);
        params.put("traveller", this.traveller);
        return params;
    }

    @Override
    public void fromMap(Map<String, Object> params) {
        fromMap(null, params);
    }

    @Override
    public void update(Map<String, Object> params) {
        fromMap(getId(), params);
    }

    public void fromMap(String id, Map<String, Object> params) {
        this.id = id;
        this.review = (java.lang.String) params.get("review");
        this.name = (java.lang.String) params.get("name");
        this.traveller = (org.acme.deals.Traveller) params.get("traveller");
    }

    @org.kie.internal.kogito.codegen.VariableInfo(tags = "")
    @com.fasterxml.jackson.annotation.JsonProperty(value = "review")
    @javax.validation.Valid()
    private java.lang.String review;

    public java.lang.String getReview() {
        return review;
    }

    public void setReview(java.lang.String review) {
        this.review = review;
    }

    @org.kie.internal.kogito.codegen.VariableInfo(tags = "")
    @com.fasterxml.jackson.annotation.JsonProperty(value = "name")
    @javax.validation.Valid()
    private java.lang.String name;

    public java.lang.String getName() {
        return name;
    }

    public void setName(java.lang.String name) {
        this.name = name;
    }

    @org.kie.internal.kogito.codegen.VariableInfo(tags = "")
    @com.fasterxml.jackson.annotation.JsonProperty(value = "traveller")
    @javax.validation.Valid()
    private org.acme.deals.Traveller traveller;

    public org.acme.deals.Traveller getTraveller() {
        return traveller;
    }

    public void setTraveller(org.acme.deals.Traveller traveller) {
        this.traveller = traveller;
    }

    public DealsModelOutput toOutput() {
        DealsModelOutput result = new DealsModelOutput();
        result.setId(getId());
        result.setReview(getReview());
        result.setName(getName());
        result.setTraveller(getTraveller());
        return result;
    }
}
